@@ -63,7 +63,7 @@ class RandomUA:
         cls.__optionally_load()
 
         if not browser_name and not min_browser_version and not max_browser_version:
-            return random.choice(cls.db['_default'].values())['ua']
+            return random.choice(cls.db.all())['ua']
         
         min_browser_version = min_browser_version or 0
         max_browser_version = max_browser_version or 999999999
